<?php

class Application_Model_CaseLogic extends Application_Model_Case
{
    
    public function fetchOrdered()
    {
        return $this->fetchAll($this->select()->order('id desc'));
    }
    
    public function fetchDataTableSelect($key = null) 
    {
        $columns = array('case_id', 'case_num', 'case_name', 'case_address', 'case_mobile', 'action');
        $obj_data = new Application_Model_Util_Datatable((new Application_Model_View_Case(-1)), $columns);
        $where = $obj_data->get_where();
        $where->where('case_status != ?', 'D');
        if(null != $key) {
            $where->where('md5(case_status) = ?', $key);
            if($key == 'c81e728d9d4c2f636f067f89cc14862c') {
                $where->where('DATE(sched_time) = ?', date('Y-m-d'));
            }
        } else {
            $obj_user = new Application_Model_UserLogic(-1);
            $user = $obj_user->getLoggedInUser();
            $roleStatus = Application_Model_Cache_Config::getConfig('CASE_VISIBILITY_ROLE');
            $where->where('case_status in ('.implode(', ', $roleStatus[$user->get_user_role()]).')');
        }
        $obj_data->set_where($where);
        $rows = $obj_data->fetch();
        $results = array();
        $i = 0;
        $url = new Zend_View_Helper_Url();
        $enc = new Application_Model_Util_Encrypt();
        foreach($rows as $row)
        {
            $action = '';
            if(Application_Model_RolePermissionLogic::isPermitted("Case:Home")) {
                $action = '<a href="'.$url->url(array("controller"=>"case", "action"=>"view", "id"=>$enc->hideContent($row->id))).'"><input type="button" value="Enter" class="btn btn-info" /></a> ';
            }
            if(Application_Model_RolePermissionLogic::isPermitted("Case:Edit")) {
                $action .= '<a href="'.$url->url(array("controller"=>"case", "action"=>"edit", "id"=>$enc->hideContent($row->id))).'"><input type="button" value="Edit" class="btn btn-info" /></a> ';
            }
            if(Application_Model_RolePermissionLogic::isPermitted("Case:Delete")) {
                //$action .= '<a href="'.$url->url(array("controller"=>"case", "action"=>"delete", "id"=>$enc->hideContent($row->id))).'"><input type="button" value="Delete" class="btn btn-danger" /></a>';
            }
            $results[$i] = array($row->case_id, $row->case_num, $row->case_name, '<div style="width: 200px; word-wrap: break-word;">'.$row->case_address.'</div>', $row->case_mobile, Application_Model_CaseStatus::$status[$row->case_status], $action);
            $i += 1;
        }
        return $obj_data->configureOutput($results);
    }
    
    public function isCaseNumExist($num)
    {
        return (count($this->fetchAll($this->select()->where('case_num = ?', $num)->where('case_status != ?', 'D'))) > 0) ? true : false;
    }
    
    public function updateCaseStatus($caseId, $status)
    {
        $user = new Application_Model_UserLogic(-1);
        $this->set_id($caseId);
        $this->fetch();
        $this->set_case_status($status);
        $this->set_case_status_date(date('Y-m-d H:i:s'));
        $this->set_case_updated_by($user->getLoggedInUserId());
        $this->save();
    }
    
    public function generateCaseId()
    {
        $totalCase = count($this->fetchAll($this->select()->where('YEAR(case_created_date) = ?', date('Y'))->where('MONTH(case_created_date) = ?', date('m')))) + 1;
        $caseId  = date('Ym').  str_pad($totalCase, 4, "0", STR_PAD_LEFT);
        return $caseId;
    }
    
    public function getScheduledCase($start, $end)
    {
        $obj_case = new Application_Model_View_Case(-1);
        $where = $obj_case->select()->where('case_status = ?', Application_Model_CaseStatus::CASE_STATUS_ID_SCHEDULED)->where('DATE(sched_time) >= ?', $start)->where('DATE(sched_time) <= ?', $end);
        return $this->fetchAll($where);
    }
    
    public function getInstalledCase($start, $end)
    {
        $obj_case = new Application_Model_View_Case(-1);
        $where = $obj_case->select()->where('case_status = ?', Application_Model_CaseStatus::CASE_STATUS_ID_INSTALLED)->where('DATE(install_date) >= ?', $start)->where('DATE(install_date) <= ?', $end);
        return $this->fetchAll($where);
    }
    
    public function getInvoicedCase($start, $end)
    {
        $obj_case = new Application_Model_View_Case(-1);
        $where = $obj_case->select()->where('case_status = ?', Application_Model_CaseStatus::CASE_STATUS_ID_INVOICE)->where('DATE(invoice_date) >= ?', $start)->where('DATE(invoice_date) <= ?', $end);
        return $this->fetchAll($where);
    }
    
    public function getClosedCase($start, $end)
    {
        $obj_case = new Application_Model_View_Case(-1);
        $where = $obj_case->select()->where('case_status = ?', Application_Model_CaseStatus::CASE_STATUS_ID_CLOSED)->where('DATE(case_status_date) >= ?', $start)->where('DATE(case_status_date) <= ?', $end);
        return $this->fetchAll($where);
    }
}

