<?php

class Application_Model_Report extends Application_Model_View_Case
{
    
    public static $input_columns = ['case_id', 'case_num', 'case_account', 'case_mobile', 'case_date', 'case_status', 'sched_ac_type', 
        'sched_ac_capacity', 'install_unique_id', 'install_ac_make', 'install_ac_model', 'install_ac_capacity', 'case_created_date', 'sched_time',
        'install_date', 'invoice_num', 'invoice_date', 'case_status_date'];
    
    public static $input_tags = ['Unique Identification No', 'Notification No.', 'Contract Account', 'Mobile', 'Created Date', "Status", 'Schedule AC Type',
        'Schedule AC Capacity', 'Unique ID', 'Install AC Make', 'Install AC Model', 'Install AC Capacity', 'Registered Date', 'Scheduled Date',
        'Install Date', 'Invoice Number', 'Invoice Date', 'Close Date'];
    
    public static $output_columns = ['case_num', 'case_account', 'case_name', 'case_address', 'install_ac_make', 'install_ac_model', 'install_ac_capacity',
        'install_srn', 'invoice_num', 'invoice_date', 'invoice_net_amount', 'invoice_rebate_amount', 'retail_layout', 'retail_layout_address', 'install_date',
        'install_old_make', 'install_old_model', 'install_old_capacity', 'install_old_year', 'install_old_srn', 'install_old_dispose', 'install_old_vendor', 'invoice_disposal_amount', 'install_old_watt', 'install_unique_id'];
    
    public static $output_tags = ['S.N.', 'Notification No.', 'Conact Account', 'Name of the Applicant', 'Address of the new installaed AC', 'Make of New AC',
        'Model of new AC', 'Capacity of new AC in ton', 'Mfg. Serial No. of new AC', 'Invoice no.', 'Invoice Date', 'Net Sale Amount (Rs.)',
        'Rebate Amount (Rs.)', 'Name of the retail outlet', 'Address of the retail outlet', 'Date of installation at Site', 'Make of Old AC',
        'MODEL OF OLD AC', 'Capacity of old AC in ton', 'Mfg. Year of old AC', 'SERIAL NO OF OLD AC', 'Date of disposal of old AC',
        'Name of the vendor for disposing old AC', 'Amount paid to consumer against disposal (RS.)', 'WATTS', 'Unique Identification No.'];
            
    public function __construct($id)
    {
        parent::__construct($id);
        $id = (int) $id;
        $this->set_id($id);
        if($id!=-1)
        {
          $this->fetch();
        }
    }
    
    public function getFilterQuery($filter = null, $query = null, $orderBy = null, $orderDirection = null)
    {
        //Zend_Debug::dump($filter);
        if($filter == null && $query == null) {
            return null;
        }
        
        $rangeFields = array('case_date', 'case_created_date', 'sched_time', 'install_date', 'invoice_date', 'case_status_date');
        $where = $this->select()->where('case_status != ?', 'D');
        if($filter != null) {
            foreach(self::$input_columns as $col) {
                if(!empty($col) && $filter[$col] != null) {
                    if(in_array($col, $rangeFields)) {
                        $where->where('DATE('.$col.') >= ?', $filter[$col.'_from'])->where('DATE('.$col.') <= ?', $filter[$col.'_to']);
                        if($col == 'case_status_date') {
                            $where->where('case_status = ?', Application_Model_CaseStatus::CASE_STATUS_ID_CLOSED);
                        }
                    }else {
                        $where->where($col.' = ?', $filter[$col]);
                    }
                }
            }
        }
        
        $select = $this->select();
        if($query != null) {
            $select->orWhere('case_id like ?', '%'.$query.'%')
                    ->orWhere('case_num like ?', '%'.$query.'%')
                    ->orWhere('case_account like ?', '%'.$query.'%')
                    ->orWhere('LOWER(case_name) like ?', '%'.strtolower($query).'%')
                    ->orWhere('LOWER(case_address) like ?', '%'.strtolower($query).'%')
                    ->orWhere('case_mobile like ?', '%'.$query.'%')
                    ->orWhere('case_mobile_other like ?', '%'.$query.'%')
                    ->orWhere('LOWER(case_short_code) like ?', '%'.strtolower($query).'%')
                    ->orWhere('LOWER(case_segment) like ?', '%'.strtolower($query).'%')
                    ->orWhere('LOWER(case_conn_type) like ?', '%'.strtolower($query).'%')
                    ->orWhere('LOWER(case_rate_cat) like ?', '%'.strtolower($query).'%')
                    ->orWhere('LOWER(sched_ac_type) like ?', '%'.strtolower($query).'%')
                    ->orWhere('LOWER(sched_ac_capacity) like ?', '%'.strtolower($query).'%')
                    ->orWhere('LOWER(sched_remarks) like ?', '%'.strtolower($query).'%')
                    ->orWhere('LOWER(install_ac_make) like ?', '%'.strtolower($query).'%')
                    ->orWhere('LOWER(install_ac_model) like ?', '%'.strtolower($query).'%')
                    ->orWhere('LOWER(install_ac_capacity) like ?', '%'.strtolower($query).'%')
                    ->orWhere('LOWER(install_remarks) like ?', '%'.strtolower($query).'%')
                    ->orWhere('LOWER(install_old_make) like ?', '%'.strtolower($query).'%')
                    ->orWhere('LOWER(install_old_model) like ?', '%'.strtolower($query).'%')
                    ->orWhere('LOWER(install_old_vendor) like ?', '%'.strtolower($query).'%')
                    ->orWhere('LOWER(install_old_capacity) like ?', '%'.strtolower($query).'%')
                    ->orWhere('LOWER(install_srn) like ?', '%'.strtolower($query).'%')
                    ->orWhere('LOWER(install_unique_id) like ?', '%'.strtolower($query).'%')
                    ->orWhere('LOWER(install_old_srn) like ?', '%'.strtolower($query).'%')
                    ->orWhere('LOWER(invoice_num) like ?', '%'.strtolower($query).'%')
                    ->orWhere('LOWER(invoice_remarks) like ?', '%'.strtolower($query).'%');
            if(date('Y-m-d', strtotime($query)) != '1970-01-01') {
                $select->orWhere('case_date = ?', date('Y-m-d', strtotime($query)))
                    ->orWhere('sched_time = ?', date('Y-m-d', strtotime($query)))
                    ->orWhere('install_date = ?', date('Y-m-d', strtotime($query)))
                    ->orWhere('invoice_date = ?', date('Y-m-d', strtotime($query)))
                    ->orWhere('case_status_date = ?', date('Y-m-d', strtotime($query)));
            }
            $where->where(implode(' ', $select->getPart(Zend_Db_Select::WHERE)));
        }
        $order = '';
        $order .= ($orderBy != null) ? $orderBy : 'id';
        $order .= ($orderDirection != null) ? ' '.$orderDirection : ' desc';
        
        $where->order($order);
       // echo $where;
        return $where;
    }
    
    public function getFilterResults($filter = null, $query = null, $orderBy = null, $orderDirection = null)
    {
       return $this->fetchAll($this->getFilterQuery($filter, $query, $orderBy, $orderDirection));
    }
    
    public function exportToCSV($filter = null, $query = null, $orderBy = null, $orderDirection = null)
    {
        $oplist = array();
        array_push($oplist, self::$output_tags);
        $date_columns = ['case_date', 'invoice_date', 'install_date'];
        $results = $this->getFilterResults($filter, $query, $orderBy, $orderDirection);
        $i = 0;
        foreach($results as $row) {
            $op = array(); $i +=1;
            array_push($op, $i);
            foreach(self::$output_columns as $col) {
                if(in_array($col, $date_columns)) {
                    array_push($op, (date('d-M-Y', strtotime($row[$col])) != '01-Jan-1970') ? date('d-M-Y', strtotime($row[$col])) : '');
                }else {
                    array_push($op, $row[$col]);
                }
            }
            array_push($oplist, $op);
        }
        $temp_memory = fopen('php://memory', 'w');
        // loop through the array
        foreach ($oplist as $line) {
            // use the default csv handler
            fputcsv($temp_memory, $line, ",");
        }

        fseek($temp_memory, 0);
        // modify the header to be CSV format
        header('Content-Type: application/csv');
        header('Content-Disposition: attachement; filename="Aircon_Case.csv";');
        // output the file to be downloaded
        fpassthru($temp_memory);
    }
}

